@@ -363,7 +363,7 @@ class RussoundClient:
         self, device_str: str, key: str, value: str
     ) -> Coroutine[Any, Any, str]:
         """Set a zone variable to a new value."""
-        return self.request(f'SET {device_str}.{key}="{value}"')
+        return await self.request(f'SET {device_str}.{key}="{value}"')
 
     async def get_variable(self, device_str: str, key: str) -> str:
         """Retrieve the current value of a zone variable.  If the variable is
@@ -526,8 +526,9 @@ class ZoneControlSurface(Zone, AbstractControlSurface):
 
     async def set_loudness(self, loudness: bool) -> None:
         """Set the loudness of the zone."""
-        cmd = f"SET {self.device_str}.loudness {'ON' if loudness else 'OFF'}"
-        return await self.client.request(cmd)
+        await self.client.set_variable(
+            self.device_str, "loudness", "ON" if loudness else "OFF"
+        )
 
 
 @dataclass
